@@ -30,6 +30,32 @@ class SnowflakeTypeConverter(BaseTypeConverter):
 
     def convert(self, value: Any, target_type: Type) -> Any:
         """Convert Snowflake result value to target type."""
+        # Handle None/NULL values first
+        if value is None:
+            return None
+
+        # Handle Optional types
+        if self.is_optional_type(target_type):
+            if value is None:
+                return None
+            target_type = self.get_optional_inner_type(target_type)
+
+        # Handle dict/map types from Snowflake VARIANT columns
+        if hasattr(target_type, "__origin__") and target_type.__origin__ is dict:
+            # Snowflake returns VARIANT types as Python dicts already
+            if isinstance(value, dict):
+                return value
+            # If it's a string, parse it
+            elif isinstance(value, str):
+                import json
+
+                try:
+                    return json.loads(value)
+                except json.JSONDecodeError:
+                    return {}
+            else:
+                return {}
+
         # Snowflake returns proper Python types in most cases, so use base converter
         return super().convert(value, target_type)
 
@@ -248,7 +274,11 @@ class SnowflakeAdapter(DatabaseAdapter):
                     if non_none_types:
                         col_type = non_none_types[0]
 
-                snowflake_type = type_mapping.get(col_type, "VARCHAR")
+                # Handle dict/map types
+                if hasattr(col_type, "__origin__") and col_type.__origin__ is dict:
+                    snowflake_type = "VARIANT"
+                else:
+                    snowflake_type = type_mapping.get(col_type, "VARCHAR")
                 column_defs.append(f'"{col_name}" {snowflake_type}')
 
             columns_sql = ",\n  ".join(column_defs)
